CustomStatRegistry

Struct CustomStatRegistry 

pub struct CustomStatRegistry {
    custom_stats_by_id: Vec<CustomStatRef>,
    custom_stats_by_key: FxHashMap<Identifier, usize>,
    allows_registering: bool,
}
Contains all the stats that can be found in the General tab in the Statistics menu.

These stats are called ‘custom’ because they are manually defined. Vanilla defines its own custom stats, which have been extracted to generate definitions used by Steel.

Therefore, ‘custom’ here should not be misinterpreted to mean Steel’s custom stats.

Fields

custom_stats_by_id: Vec<CustomStatRef>custom_stats_by_key: FxHashMap<Identifier, usize>allows_registering: bool

Implementations

Source

impl CustomStatRegistry

pub fn new() -> Self

Source

impl CustomStatRegistry

pub fn register(&mut self, entry: CustomStatRef) -> usize

pub fn iter(&self) -> impl Iterator<Item = (usize, CustomStatRef)> + '_