pub struct CustomStat {
pub key: Identifier,
}Expand description
A custom stat definition, which represents a particular stat in the General tab in the Statistics menu. This just contains an identifier which identifies the stat.
These stats are called ‘custom’ because they are manually defined. Vanilla defines its own custom stats, which have been extracted to generate definitions used by Steel.
Therefore, ‘custom’ here should not be misinterpreted to mean Steel’s custom stats.
Fields
key: IdentifierTrait Implementations